@@ -11,6 +11,7 @@ Usage::
     from mypy_boto3_s3outposts.client import S3OutpostsClient
     from mypy_boto3_s3outposts.paginator import (
         ListEndpointsPaginator,
+        ListOutpostsWithS3Paginator,
         ListSharedEndpointsPaginator,
     )
 
@@ -18,21 +19,22 @@ Usage::
     client: S3OutpostsClient = session.client("s3outposts")
 
     list_endpoints_paginator: ListEndpointsPaginator = client.get_paginator("list_endpoints")
+    list_outposts_with_s3_paginator: ListOutpostsWithS3Paginator = client.get_paginator("list_outposts_with_s3")
     list_shared_endpoints_paginator: ListSharedEndpointsPaginator = client.get_paginator("list_shared_endpoints")
     ```
 """
 from typing import Generic, Iterator, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     ListEndpointsResultTypeDef,
+    ListOutpostsWithS3ResultTypeDef,
     ListSharedEndpointsResultTypeDef,
     PaginatorConfigTypeDef,
 )
 
-__all__ = ("ListEndpointsPaginator", "ListSharedEndpointsPaginator")
+__all__ = ("ListEndpointsPaginator", "ListOutpostsWithS3Paginator", "ListSharedEndpointsPaginator")
 
 
 _ItemTypeDef = TypeVar("_ItemTypeDef")
@@ -45,14 +47,14 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListEndpointsPaginator(Boto3Paginator):
+class ListEndpointsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Paginator.ListEndpoints)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/paginators/#listendpointspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListEndpointsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Paginator.ListEndpoints.paginate)
@@ -60,14 +62,29 @@ class ListEndpointsPaginator(Boto3Paginator):
         """
 
 
-class ListSharedEndpointsPaginator(Boto3Paginator):
+class ListOutpostsWithS3Paginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Paginator.ListOutpostsWithS3)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/paginators/#listoutpostswiths3paginator)
+    """
+
+    def paginate(
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListOutpostsWithS3ResultTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Paginator.ListOutpostsWithS3.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/paginators/#listoutpostswiths3paginator)
+        """
+
+
+class ListSharedEndpointsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Paginator.ListSharedEndpoints)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/paginators/#listsharedendpointspaginator)
     """
 
     def paginate(
-        self, *, OutpostId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, OutpostId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListSharedEndpointsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3outposts.html#S3Outposts.Paginator.ListSharedEndpoints.paginate)
