@@ -25,18 +25,24 @@ else:
 
 __all__ = (
     "CreateEndpointRequestRequestTypeDef",
-    "CreateEndpointResultTypeDef",
+    "ResponseMetadataTypeDef",
     "DeleteEndpointRequestRequestTypeDef",
-    "EndpointTypeDef",
-    "ListEndpointsRequestListEndpointsPaginateTypeDef",
-    "ListEndpointsRequestRequestTypeDef",
-    "ListEndpointsResultTypeDef",
-    "ListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef",
-    "ListSharedEndpointsRequestRequestTypeDef",
-    "ListSharedEndpointsResultTypeDef",
+    "FailedReasonTypeDef",
     "NetworkInterfaceTypeDef",
     "PaginatorConfigTypeDef",
-    "ResponseMetadataTypeDef",
+    "ListEndpointsRequestRequestTypeDef",
+    "ListOutpostsWithS3RequestRequestTypeDef",
+    "OutpostTypeDef",
+    "ListSharedEndpointsRequestRequestTypeDef",
+    "CreateEndpointResultTypeDef",
+    "EmptyResponseMetadataTypeDef",
+    "EndpointTypeDef",
+    "ListEndpointsRequestListEndpointsPaginateTypeDef",
+    "ListOutpostsWithS3RequestListOutpostsWithS3PaginateTypeDef",
+    "ListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef",
+    "ListOutpostsWithS3ResultTypeDef",
+    "ListEndpointsResultTypeDef",
+    "ListSharedEndpointsResultTypeDef",
 )
 
 _RequiredCreateEndpointRequestRequestTypeDef = TypedDict(
@@ -63,11 +69,14 @@ class CreateEndpointRequestRequestTypeDef(
     pass
 
 
-CreateEndpointResultTypeDef = TypedDict(
-    "CreateEndpointResultTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "EndpointArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -79,28 +88,29 @@ DeleteEndpointRequestRequestTypeDef = TypedDict(
     },
 )
 
-EndpointTypeDef = TypedDict(
-    "EndpointTypeDef",
+FailedReasonTypeDef = TypedDict(
+    "FailedReasonTypeDef",
     {
-        "EndpointArn": str,
-        "OutpostsId": str,
-        "CidrBlock": str,
-        "Status": EndpointStatusType,
-        "CreationTime": datetime,
-        "NetworkInterfaces": List["NetworkInterfaceTypeDef"],
-        "VpcId": str,
-        "SubnetId": str,
-        "SecurityGroupId": str,
-        "AccessType": EndpointAccessTypeType,
-        "CustomerOwnedIpv4Pool": str,
+        "ErrorCode": str,
+        "Message": str,
     },
     total=False,
 )
 
-ListEndpointsRequestListEndpointsPaginateTypeDef = TypedDict(
-    "ListEndpointsRequestListEndpointsPaginateTypeDef",
+NetworkInterfaceTypeDef = TypedDict(
+    "NetworkInterfaceTypeDef",
     {
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "NetworkInterfaceId": str,
+    },
+    total=False,
+)
+
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
     total=False,
 )
@@ -114,36 +124,25 @@ ListEndpointsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListEndpointsResultTypeDef = TypedDict(
-    "ListEndpointsResultTypeDef",
+ListOutpostsWithS3RequestRequestTypeDef = TypedDict(
+    "ListOutpostsWithS3RequestRequestTypeDef",
     {
-        "Endpoints": List["EndpointTypeDef"],
         "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef = TypedDict(
-    "_RequiredListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef",
-    {
-        "OutpostId": str,
-    },
-)
-_OptionalListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef = TypedDict(
-    "_OptionalListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "MaxResults": int,
     },
     total=False,
 )
 
-
-class ListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef(
-    _RequiredListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef,
-    _OptionalListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef,
-):
-    pass
-
+OutpostTypeDef = TypedDict(
+    "OutpostTypeDef",
+    {
+        "OutpostArn": str,
+        "OutpostId": str,
+        "OwnerId": str,
+        "CapacityInBytes": int,
+    },
+    total=False,
+)
 
 _RequiredListSharedEndpointsRequestRequestTypeDef = TypedDict(
     "_RequiredListSharedEndpointsRequestRequestTypeDef",
@@ -168,40 +167,101 @@ class ListSharedEndpointsRequestRequestTypeDef(
     pass
 
 
+CreateEndpointResultTypeDef = TypedDict(
+    "CreateEndpointResultTypeDef",
+    {
+        "EndpointArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
+    {
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+EndpointTypeDef = TypedDict(
+    "EndpointTypeDef",
+    {
+        "EndpointArn": str,
+        "OutpostsId": str,
+        "CidrBlock": str,
+        "Status": EndpointStatusType,
+        "CreationTime": datetime,
+        "NetworkInterfaces": List[NetworkInterfaceTypeDef],
+        "VpcId": str,
+        "SubnetId": str,
+        "SecurityGroupId": str,
+        "AccessType": EndpointAccessTypeType,
+        "CustomerOwnedIpv4Pool": str,
+        "FailedReason": FailedReasonTypeDef,
+    },
+    total=False,
+)
+
+ListEndpointsRequestListEndpointsPaginateTypeDef = TypedDict(
+    "ListEndpointsRequestListEndpointsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListOutpostsWithS3RequestListOutpostsWithS3PaginateTypeDef = TypedDict(
+    "ListOutpostsWithS3RequestListOutpostsWithS3PaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+_RequiredListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef = TypedDict(
+    "_RequiredListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef",
+    {
+        "OutpostId": str,
+    },
+)
+_OptionalListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef = TypedDict(
+    "_OptionalListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef(
+    _RequiredListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef,
+    _OptionalListSharedEndpointsRequestListSharedEndpointsPaginateTypeDef,
+):
+    pass
+
+
+ListOutpostsWithS3ResultTypeDef = TypedDict(
+    "ListOutpostsWithS3ResultTypeDef",
+    {
+        "Outposts": List[OutpostTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListEndpointsResultTypeDef = TypedDict(
+    "ListEndpointsResultTypeDef",
+    {
+        "Endpoints": List[EndpointTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ListSharedEndpointsResultTypeDef = TypedDict(
     "ListSharedEndpointsResultTypeDef",
     {
-        "Endpoints": List["EndpointTypeDef"],
+        "Endpoints": List[EndpointTypeDef],
         "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-NetworkInterfaceTypeDef = TypedDict(
-    "NetworkInterfaceTypeDef",
-    {
-        "NetworkInterfaceId": str,
-    },
-    total=False,
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
